[beast: 1/5] BSE: rename BseIt3mSeq to make room for new API



commit f49347767528bcf120835eb00004a802b4ec6d53
Author: Tim Janik <timj gnu org>
Date:   Thu Nov 5 13:57:13 2015 +0100

    BSE: rename BseIt3mSeq to make room for new API
    
    Signed-off-by: Tim Janik <timj gnu org>

 beast-gtk/bstapp.cc              |    4 +-
 beast-gtk/bstbseutils.cc         |    4 +-
 beast-gtk/bstbusmixer.cc         |    2 +-
 beast-gtk/bstitemseqdialog.cc    |   12 ++++----
 beast-gtk/bstitemseqdialog.hh    |   10 +++---
 beast-gtk/bstkeybindings.cc      |   12 ++++----
 beast-gtk/bstkeybindings.hh      |    4 +-
 beast-gtk/bstparam-item-seq.cc   |   14 +++++-----
 beast-gtk/bstparam-proxy.cc      |    8 +++---
 beast-gtk/bstparam.cc            |    2 +-
 beast-gtk/bstpatternctrl.cc      |   12 ++++----
 beast-gtk/bstplayback.cc         |    8 +++---
 beast-gtk/bstpreferences.cc      |   16 ++++++------
 beast-gtk/bstsnetrouter.cc       |    2 +-
 beast-gtk/bsttracksynthdialog.cc |    4 +-
 beast-gtk/bsttracksynthdialog.hh |    4 +-
 beast-gtk/bsttrackview.cc        |   16 ++++++------
 beast-gtk/bsttreestores.cc       |   10 +++---
 beast-gtk/bsttreestores.hh       |    6 ++--
 bse/bsebasics.idl                |    4 +-
 bse/bsebus.cc                    |   52 +++++++++++++++++++-------------------
 bse/bsebus.hh                    |    4 +-
 bse/bsecontainer.cc              |   10 +++---
 bse/bsecontainer.hh              |    2 +-
 bse/bsecontainer.proc            |    2 +-
 bse/bseitem.cc                   |   14 +++++-----
 bse/bseitem.hh                   |    8 +++---
 bse/bseproject.proc              |    8 +++---
 bse/bsetrack.cc                  |   12 ++++----
 bse/bsetrack.proc                |    4 +-
 bse/bseutils.cc                  |   12 ++++----
 bse/bseutils.hh                  |    6 ++--
 bse/bsewaveosc.proc              |    4 +-
 33 files changed, 146 insertions(+), 146 deletions(-)
---
diff --git a/beast-gtk/bstapp.cc b/beast-gtk/bstapp.cc
index 064b744..828bc0a 100644
--- a/beast-gtk/bstapp.cc
+++ b/beast-gtk/bstapp.cc
@@ -542,7 +542,7 @@ bst_app_reload_pages (BstApp *self)
   SfiProxy old_item = self->ppages->selected ? (SfiProxy) self->ppages->selected->user_data : 0;
 
   /* collect page objects */
-  BseItemSeq *iseq = bse_project_get_supers (self->project.proxy_id());
+  BseIt3mSeq *iseq = bse_project_get_supers (self->project.proxy_id());
   SfiRing *ring, *proxies = NULL;
   guint i;
   for (i = 0; i < iseq->n_items; i++)
@@ -1095,7 +1095,7 @@ app_action_check (gpointer data,
   switch (action)
     {
       SfiProxy super;
-      BseItemSeq *iseq;
+      BseIt3mSeq *iseq;
       guint i;
     case BST_ACTION_NEW_PROJECT:
     case BST_ACTION_OPEN_PROJECT:
diff --git a/beast-gtk/bstbseutils.cc b/beast-gtk/bstbseutils.cc
index 331b578..a7673c8 100644
--- a/beast-gtk/bstbseutils.cc
+++ b/beast-gtk/bstbseutils.cc
@@ -10,7 +10,7 @@ bst_project_restore_from_file (Bse::ProjectH project, const gchar *file_name, bo
   /* regardless of how good the restoration worked, try to
    * keep the resulting project in a GUI usable state.
    */
-  BseItemSeq *iseq = bse_container_list_children (project.proxy_id());
+  BseIt3mSeq *iseq = bse_container_list_children (project.proxy_id());
   guint i;
   for (i = 0; i < iseq->n_items; i++)
     if (BSE_IS_SONG (iseq->items[i]))
@@ -39,7 +39,7 @@ bst_project_import_midi_file (Bse::ProjectH project, const gchar *file_name)
   /* regardless of how good the restoration worked, try to
    * keep the resulting project in a GUI usable state.
    */
-  BseItemSeq *iseq = bse_container_list_children (project.proxy_id());
+  BseIt3mSeq *iseq = bse_container_list_children (project.proxy_id());
   guint i;
   for (i = 0; i < iseq->n_items; i++)
     if (BSE_IS_SONG (iseq->items[i]))
diff --git a/beast-gtk/bstbusmixer.cc b/beast-gtk/bstbusmixer.cc
index 1c2bb98..bf66afb 100644
--- a/beast-gtk/bstbusmixer.cc
+++ b/beast-gtk/bstbusmixer.cc
@@ -158,7 +158,7 @@ bus_mixer_set_container (BstItemView *iview,
                          "signal::item_added", bus_mixer_item_added, self,
                          "signal::item_remove", bus_mixer_item_removed, self,
                          NULL);
-      BseItemSeq *iseq = bse_container_list_children (iview->container);
+      BseIt3mSeq *iseq = bse_container_list_children (iview->container);
       guint i;
       for (i = 0; i < iseq->n_items; i++)
         bus_mixer_item_added (iview->container, iseq->items[i], self);
diff --git a/beast-gtk/bstitemseqdialog.cc b/beast-gtk/bstitemseqdialog.cc
index 0dd9273..6982b60 100644
--- a/beast-gtk/bstitemseqdialog.cc
+++ b/beast-gtk/bstitemseqdialog.cc
@@ -118,10 +118,10 @@ bst_item_seq_dialog_popup (gpointer     parent_widget,
                            SfiProxy     item,
                            const gchar *candidate_label,
                            const gchar *candidate_tooltip,
-                           BseItemSeq  *candidates,
+                           BseIt3mSeq  *candidates,
                            const gchar *item_label,
                            const gchar *item_tooltip,
-                           BseItemSeq  *items,
+                           BseIt3mSeq  *items,
                            BstItemSeqDialogSelected selected_callback,
                            gpointer                 selected_data,
                            GxkFreeFunc              selected_cleanup)
@@ -162,8 +162,8 @@ bst_item_seq_dialog_popup (gpointer     parent_widget,
 
 void
 bst_item_seq_dialog_set (BstItemSeqDialog *self,
-                         BseItemSeq       *candidates,
-                         BseItemSeq       *iseq)
+                         BseIt3mSeq       *candidates,
+                         BseIt3mSeq       *iseq)
 {
   assert_return (BST_IS_ITEM_SEQ_DIALOG (self));
 
@@ -289,9 +289,9 @@ bst_item_seq_dialog_activate (BstItemSeqDialog *self)
   self->selected_cleanup = NULL;
   if (selected_callback)        /* notify popup caller */
     {
-      BseItemSeq *iseq = bst_item_seq_store_dup (self->item_store);
+      BseIt3mSeq *iseq = bst_item_seq_store_dup (self->item_store);
       selected_callback (selected_data, iseq, self);
-      bse_item_seq_free (iseq);
+      bse_it3m_seq_free (iseq);
     }
   if (selected_cleanup)
     selected_cleanup (selected_data);
diff --git a/beast-gtk/bstitemseqdialog.hh b/beast-gtk/bstitemseqdialog.hh
index abb2706..2078548 100644
--- a/beast-gtk/bstitemseqdialog.hh
+++ b/beast-gtk/bstitemseqdialog.hh
@@ -19,7 +19,7 @@ G_BEGIN_DECLS
 typedef struct _BstItemSeqDialog          BstItemSeqDialog;
 typedef struct _BstItemSeqDialogClass     BstItemSeqDialogClass;
 typedef void (*BstItemSeqDialogSelected) (gpointer             data,
-                                          BseItemSeq          *iseq,
+                                          BseIt3mSeq          *iseq,
                                           BstItemSeqDialog    *isdialog);
 struct _BstItemSeqDialog
 {
@@ -48,16 +48,16 @@ GtkWidget* bst_item_seq_dialog_popup    (gpointer                  parent_widget
                                          SfiProxy                  item,
                                          const gchar              *candidate_label,
                                          const gchar              *candidate_tooltip,
-                                         BseItemSeq               *candidates,
+                                         BseIt3mSeq               *candidates,
                                          const gchar              *item_label,
                                          const gchar              *item_tooltip,
-                                         BseItemSeq               *iseq,
+                                         BseIt3mSeq               *iseq,
                                          BstItemSeqDialogSelected  selected_callback,
                                          gpointer                  selected_data,
                                          GxkFreeFunc               selected_cleanup);
 void       bst_item_seq_dialog_set      (BstItemSeqDialog         *self,
-                                         BseItemSeq               *candidates,
-                                         BseItemSeq               *iseq);
+                                         BseIt3mSeq               *candidates,
+                                         BseIt3mSeq               *iseq);
 
 
 
diff --git a/beast-gtk/bstkeybindings.cc b/beast-gtk/bstkeybindings.cc
index 2c80b03..544febe 100644
--- a/beast-gtk/bstkeybindings.cc
+++ b/beast-gtk/bstkeybindings.cc
@@ -453,7 +453,7 @@ bst_key_binding_box_set (GtkWidget *self, Bst::KeyBindingItemSeq *kbseq)
   BstKeyBinding *kbinding = (BstKeyBinding*) g_object_get_data ((GObject*) self, "BstKeyBinding");
   GtkTreeView *btview = (GtkTreeView*) gxk_radget_find (self, "binding-tree-view");
   GtkTreeModel *model = gtk_tree_view_get_model (btview);
-  bst_key_binding_set_item_seq (kbinding, *kbseq);
+  bst_key_binding_set_it3m_seq (kbinding, *kbseq);
   gxk_list_wrapper_notify_clear (GXK_LIST_WRAPPER (model));
   gxk_list_wrapper_notify_append (GXK_LIST_WRAPPER (model), kbinding->n_keys);
 }
@@ -462,7 +462,7 @@ Bst::KeyBindingItemSeq*
 bst_key_binding_box_get_new (GtkWidget *self)
 {
   BstKeyBinding *kbinding = (BstKeyBinding*) g_object_get_data ((GObject*) self, "BstKeyBinding");
-  return bst_key_binding_get_new_item_seq (kbinding);
+  return bst_key_binding_get_new_it3m_seq (kbinding);
 }
 
 BstKeyBindingKey*
@@ -518,7 +518,7 @@ key_binding_find_function (BstKeyBinding *kbinding,
 }
 
 void
-bst_key_binding_set_item_seq (BstKeyBinding *kbinding, const Bst::KeyBindingItemSeq &seq)
+bst_key_binding_set_it3m_seq (BstKeyBinding *kbinding, const Bst::KeyBindingItemSeq &seq)
 {
   BstKeyBindingKey *key;
   guint i;
@@ -547,7 +547,7 @@ bst_key_binding_set_item_seq (BstKeyBinding *kbinding, const Bst::KeyBindingItem
 }
 
 Bst::KeyBindingItemSeq*
-bst_key_binding_get_new_item_seq (BstKeyBinding *kbinding)
+bst_key_binding_get_new_it3m_seq (BstKeyBinding *kbinding)
 {
   Bst::KeyBindingItemSeq *iseq = new Bst::KeyBindingItemSeq();
   for (size_t i = 0; i < kbinding->n_keys; i++)
@@ -619,7 +619,7 @@ bst_key_binding_dump (const gchar *file_name,
   for (slist = kbindings; slist; slist = slist->next)
     {
       BstKeyBinding *kbinding = (BstKeyBinding*) slist->data;
-      Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_item_seq (kbinding);
+      Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_it3m_seq (kbinding);
       GParamSpec *pspec = sfi_pspec_seq (kbinding->binding_name, NULL, NULL, bst_key_binding_item_pspec(), 
SFI_PARAM_STANDARD);
       SfiSeq *seq = Bse::sfi_seq_new_from_visitable (*iseq);
       GValue *value = sfi_value_seq (seq);
@@ -663,7 +663,7 @@ key_binding_try_statement (gpointer   context_data,
             {
               Bst::KeyBindingItemSeq iseq;
               Bse::sfi_seq_to_visitable (seq, iseq);
-              bst_key_binding_set_item_seq (kbinding, iseq);
+              bst_key_binding_set_it3m_seq (kbinding, iseq);
             }
           sfi_value_free (value);
           return token;
diff --git a/beast-gtk/bstkeybindings.hh b/beast-gtk/bstkeybindings.hh
index 459faa9..918b68b 100644
--- a/beast-gtk/bstkeybindings.hh
+++ b/beast-gtk/bstkeybindings.hh
@@ -63,8 +63,8 @@ guint                        bst_key_binding_lookup_id    (BstKeyBinding
                                                            GdkModifierType              modifier,
                                                            guint                        collision_group,
                                                            gdouble                     *param);
-void                         bst_key_binding_set_item_seq (BstKeyBinding *kbinding, const 
Bst::KeyBindingItemSeq &seq);
-Bst::KeyBindingItemSeq*  bst_key_binding_get_new_item_seq (BstKeyBinding *kbinding);
+void                         bst_key_binding_set_it3m_seq (BstKeyBinding *kbinding, const 
Bst::KeyBindingItemSeq &seq);
+Bst::KeyBindingItemSeq*  bst_key_binding_get_new_it3m_seq (BstKeyBinding *kbinding);
 const gchar*                 bst_key_binding_rcfile       (void);
 Bse::ErrorType                 bst_key_binding_dump         (const gchar                 *file_name,
                                                            GSList                      *kbindings);
diff --git a/beast-gtk/bstparam-item-seq.cc b/beast-gtk/bstparam-item-seq.cc
index 239624c..c477653 100644
--- a/beast-gtk/bstparam-item-seq.cc
+++ b/beast-gtk/bstparam-item-seq.cc
@@ -5,14 +5,14 @@
 #include "bstitemseqdialog.hh"
 static void
 param_item_seq_changed (gpointer             data,
-                        BseItemSeq          *iseq,
+                        BseIt3mSeq          *iseq,
                         BstItemSeqDialog    *isdialog)
 {
   GxkParam *param = (GxkParam*) data;
   SfiProxy proxy = bst_param_get_proxy (param);
   if (proxy)
     {
-      SfiSeq *seq = bse_item_seq_to_seq (iseq);
+      SfiSeq *seq = bse_it3m_seq_to_seq (iseq);
       sfi_value_take_seq (&param->value, seq);
       gxk_param_apply_value (param);
     }
@@ -27,13 +27,13 @@ param_item_seq_popup_editor (GtkWidget *widget,
     {
       BsePropertyCandidates *pc = bse_item_get_property_candidates (proxy, param->pspec->name);
       SfiSeq *seq = (SfiSeq*) g_value_get_boxed (&param->value);
-      BseItemSeq *iseq = bse_item_seq_from_seq (seq);
+      BseIt3mSeq *iseq = bse_it3m_seq_from_seq (seq);
       bst_item_seq_dialog_popup (widget, proxy,
                                  pc->label, pc->tooltip, pc->items,
                                  g_param_spec_get_nick (param->pspec), g_param_spec_get_blurb 
(param->pspec), iseq,
                                  param_item_seq_changed,
                                  param, NULL);
-      bse_item_seq_free (iseq);
+      bse_it3m_seq_free (iseq);
     }
 }
 
@@ -87,7 +87,7 @@ param_item_seq_update (GxkParam  *param,
     {
       BsePropertyCandidates *pc = bse_item_get_property_candidates (proxy, param->pspec->name);
       SfiSeq *seq = (SfiSeq*) g_value_get_boxed (&param->value);
-      BseItemSeq *iseq = seq ? bse_item_seq_from_seq (seq) : NULL;
+      BseIt3mSeq *iseq = seq ? bse_it3m_seq_from_seq (seq) : NULL;
       if (iseq)
         {
           if (iseq->n_items == 1)
@@ -116,7 +116,7 @@ param_item_seq_update (GxkParam  *param,
                 g_string_append_printf (gstring, " & #%u", other);
               content = g_string_free (gstring, FALSE);
             }
-          bse_item_seq_free (iseq);
+          bse_it3m_seq_free (iseq);
         }
     }
   GtkWidget *label = (GtkWidget*) g_object_get_data ((GObject*) widget, "beast-GxkParam-label");
@@ -126,7 +126,7 @@ param_item_seq_update (GxkParam  *param,
   g_free (content);
 }
 
-static GxkParamEditor param_item_seq = {
+static GxkParamEditor param_it3m_seq = {
   { "item-list",        N_("Item List"), },
   { G_TYPE_BOXED,       "SfiSeq", },
   { "item-sequence",    +5,     TRUE, },        /* options, rating, editing */
diff --git a/beast-gtk/bstparam-proxy.cc b/beast-gtk/bstparam-proxy.cc
index f1fd47e..ac42133 100644
--- a/beast-gtk/bstparam-proxy.cc
+++ b/beast-gtk/bstparam-proxy.cc
@@ -4,7 +4,7 @@
 
 /* --- SfiProxy parameter editors --- */
 typedef struct {
-  BseItemSeq *iseq;
+  BseIt3mSeq *iseq;
   gchar      **paths;
   gchar       *prefix;
 } ParamProxyPopulation;
@@ -14,7 +14,7 @@ param_proxy_free_population (gpointer p)
   ParamProxyPopulation *pop = (ParamProxyPopulation*) p;
   g_strfreev (pop->paths);
   g_free (pop->prefix);
-  bse_item_seq_free (pop->iseq);
+  bse_it3m_seq_free (pop->iseq);
   g_free (pop);
 }
 
@@ -39,7 +39,7 @@ param_proxy_populate (GtkWidget *chunter,
   if (pc && pc->items)
     {
       pop = g_new (ParamProxyPopulation, 1);
-      pop->iseq = bse_item_seq_copy_shallow (pc->items);
+      pop->iseq = bse_it3m_seq_copy_shallow (pc->items);
       pop->paths = NULL;
       pop->prefix = NULL;
       /* go from object to path name */
@@ -166,7 +166,7 @@ bst_item_seq_list_match (GSList      *item_seq_slist,
   l = strlen (text);
   for (slist = item_seq_slist; slist; slist = slist->next)
     {
-      BseItemSeq *iseq = (BseItemSeq*) slist->data;
+      BseIt3mSeq *iseq = (BseIt3mSeq*) slist->data;
       for (i = 0; i < iseq->n_items; i++)
        {
          const gchar *path = bse_item_get_uname_path (iseq->items[i]);
diff --git a/beast-gtk/bstparam.cc b/beast-gtk/bstparam.cc
index 8c7b6c6..da59999 100644
--- a/beast-gtk/bstparam.cc
+++ b/beast-gtk/bstparam.cc
@@ -558,7 +558,7 @@ _bst_init_params (void)
   gxk_param_register_editor (&param_note_spinner_int, NULL);
   gxk_param_register_editor (&param_note_spinner_num, NULL);
   gxk_param_register_editor (&param_proxy, NULL);
-  gxk_param_register_editor (&param_item_seq, NULL);
+  gxk_param_register_editor (&param_it3m_seq, NULL);
   gxk_param_register_editor (&param_automation, NULL);
   gxk_param_register_editor (&param_scale1, NULL);
   gxk_param_register_editor (&param_scale2, NULL);
diff --git a/beast-gtk/bstpatternctrl.cc b/beast-gtk/bstpatternctrl.cc
index a42cc29..159f466 100644
--- a/beast-gtk/bstpatternctrl.cc
+++ b/beast-gtk/bstpatternctrl.cc
@@ -504,7 +504,7 @@ bst_pattern_controller_default_generic_keys (void)
       Bst::KeyBindingItemSeq iseq;
       for (size_t i = 0; i < G_N_ELEMENTS (dflt_keys); i++)
         iseq.push_back (key_binding_item_from_static (dflt_keys[i]));
-      bst_key_binding_set_item_seq (&kbinding, iseq);
+      bst_key_binding_set_it3m_seq (&kbinding, iseq);
     }
   return &kbinding;
 }
@@ -524,7 +524,7 @@ bst_pattern_controller_default_piano_keys (void)
       // setup default keys
       for (size_t i = 0; i < G_N_ELEMENTS (dflt_keys); i++)
         iseq.push_back (key_binding_item_from_static (dflt_keys[i]));
-      bst_key_binding_set_item_seq (&kbinding, iseq);
+      bst_key_binding_set_it3m_seq (&kbinding, iseq);
     }
   return &kbinding;
 }
@@ -538,8 +538,8 @@ bst_pattern_controller_generic_keys (void)
       BstKeyBinding *dflt_kbinding = bst_pattern_controller_default_generic_keys();
       kbinding.funcs = pattern_controller_get_functions (FALSE, &kbinding.n_funcs);
       // copy keys
-      Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_item_seq (dflt_kbinding);
-      bst_key_binding_set_item_seq (&kbinding, *iseq);
+      Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_it3m_seq (dflt_kbinding);
+      bst_key_binding_set_it3m_seq (&kbinding, *iseq);
       delete iseq;
     }
   return &kbinding;
@@ -554,8 +554,8 @@ bst_pattern_controller_piano_keys (void)
       BstKeyBinding *dflt_kbinding = bst_pattern_controller_default_piano_keys();
       kbinding.funcs = pattern_controller_get_functions (TRUE, &kbinding.n_funcs);
       // copy keys
-      Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_item_seq (dflt_kbinding);
-      bst_key_binding_set_item_seq (&kbinding, *iseq);
+      Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_it3m_seq (dflt_kbinding);
+      bst_key_binding_set_it3m_seq (&kbinding, *iseq);
       delete iseq;
     }
   return &kbinding;
diff --git a/beast-gtk/bstplayback.cc b/beast-gtk/bstplayback.cc
index 1e63f2f..e73fb8d 100644
--- a/beast-gtk/bstplayback.cc
+++ b/beast-gtk/bstplayback.cc
@@ -68,14 +68,14 @@ void
 bst_play_back_handle_seek_perc (BstPlayBackHandle *handle,
                                gfloat             perc)
 {
-  BseItemSeq *iseq = bse_item_seq_new();
-  bse_item_seq_append (iseq, handle->wosc1);
+  BseIt3mSeq *iseq = bse_it3m_seq_new();
+  bse_it3m_seq_append (iseq, handle->wosc1);
   if (handle->wosc2)
-    bse_item_seq_append (iseq, handle->wosc2);
+    bse_it3m_seq_append (iseq, handle->wosc2);
   bse_wave_osc_mass_seek_perc (iseq, perc);
   if (handle->waiting_for_notify)
     handle->discard_next_notify = TRUE;
-  bse_item_seq_free (iseq);
+  bse_it3m_seq_free (iseq);
 }
 
 void
diff --git a/beast-gtk/bstpreferences.cc b/beast-gtk/bstpreferences.cc
index 2e65d80..790a50f 100644
--- a/beast-gtk/bstpreferences.cc
+++ b/beast-gtk/bstpreferences.cc
@@ -48,14 +48,14 @@ bst_preferences_init (BstPreferences *self)
   gxk_notebook_append (self->notebook, pchild, "BEAST", FALSE);
 
   kbinding = bst_pattern_controller_piano_keys();
-  Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_item_seq (kbinding);
+  Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_it3m_seq (kbinding);
   self->box_piano_keys = bst_key_binding_box (kbinding->binding_name, kbinding->n_funcs, kbinding->funcs, 
TRUE);
   bst_key_binding_box_set (self->box_piano_keys, iseq);
   delete iseq;
   gxk_notebook_append (self->notebook, self->box_piano_keys, _("Piano Keys"), FALSE);
 
   kbinding = bst_pattern_controller_generic_keys();
-  iseq = bst_key_binding_get_new_item_seq (kbinding);
+  iseq = bst_key_binding_get_new_it3m_seq (kbinding);
   self->box_generic_keys = bst_key_binding_box (kbinding->binding_name, kbinding->n_funcs, kbinding->funcs, 
FALSE);
   bst_key_binding_box_set (self->box_generic_keys, iseq);
   delete iseq;
@@ -177,12 +177,12 @@ bst_preferences_revert (BstPreferences *self)
   sfi_rec_unref (crec);
 
   kbinding = bst_pattern_controller_piano_keys();
-  Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_item_seq (kbinding);
+  Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_it3m_seq (kbinding);
   bst_key_binding_box_set (self->box_piano_keys, iseq);
   delete iseq;
 
   kbinding = bst_pattern_controller_generic_keys();
-  iseq = bst_key_binding_get_new_item_seq (kbinding);
+  iseq = bst_key_binding_get_new_it3m_seq (kbinding);
   bst_key_binding_box_set (self->box_generic_keys, iseq);
   delete iseq;
 
@@ -218,12 +218,12 @@ bst_preferences_default_revert (BstPreferences *self)
 
   kbinding = bst_pattern_controller_piano_keys();
   (void) kbinding;
-  Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_item_seq 
(bst_pattern_controller_default_piano_keys());
+  Bst::KeyBindingItemSeq *iseq = bst_key_binding_get_new_it3m_seq 
(bst_pattern_controller_default_piano_keys());
   bst_key_binding_box_set (self->box_piano_keys, iseq);
   delete iseq;
 
   kbinding = bst_pattern_controller_generic_keys();
-  iseq = bst_key_binding_get_new_item_seq (bst_pattern_controller_default_generic_keys());
+  iseq = bst_key_binding_get_new_it3m_seq (bst_pattern_controller_default_generic_keys());
   bst_key_binding_box_set (self->box_generic_keys, iseq);
   delete iseq;
 
@@ -253,12 +253,12 @@ bst_preferences_apply (BstPreferences *self)
 
   kbinding = bst_pattern_controller_piano_keys();
   Bst::KeyBindingItemSeq *iseq = bst_key_binding_box_get_new (self->box_piano_keys);
-  bst_key_binding_set_item_seq (kbinding, *iseq);
+  bst_key_binding_set_it3m_seq (kbinding, *iseq);
   delete iseq;
 
   kbinding = bst_pattern_controller_generic_keys();
   iseq = bst_key_binding_box_get_new (self->box_generic_keys);
-  bst_key_binding_set_item_seq (kbinding, *iseq);
+  bst_key_binding_set_it3m_seq (kbinding, *iseq);
   delete iseq;
 
   Bst::MsgAbsorbStringSeq *mass = bst_msg_absorb_config_box_get (self->box_msg_absorb_config);
diff --git a/beast-gtk/bstsnetrouter.cc b/beast-gtk/bstsnetrouter.cc
index 0bc540d..3a3c1d1 100644
--- a/beast-gtk/bstsnetrouter.cc
+++ b/beast-gtk/bstsnetrouter.cc
@@ -331,7 +331,7 @@ void
 bst_snet_router_update (BstSNetRouter *self)
 {
   GnomeCanvas *canvas;
-  BseItemSeq *iseq;
+  BseIt3mSeq *iseq;
   GSList *slist, *csources = NULL;
   guint i;
 
diff --git a/beast-gtk/bsttracksynthdialog.cc b/beast-gtk/bsttracksynthdialog.cc
index 697ae2a..b8cc109 100644
--- a/beast-gtk/bsttracksynthdialog.cc
+++ b/beast-gtk/bsttracksynthdialog.cc
@@ -217,7 +217,7 @@ bst_track_synth_dialog_popup (gpointer     parent_widget,
                               SfiProxy     track,
                               const gchar *candidate_label,
                               const gchar *candidate_tooltip,
-                              BseItemSeq  *candidates,
+                              BseIt3mSeq  *candidates,
                               const gchar *wrepo_label,
                               const gchar *wrepo_tooltip,
                               SfiProxy     wrepo,
@@ -255,7 +255,7 @@ bst_track_synth_dialog_popup (gpointer     parent_widget,
 
 void
 bst_track_synth_dialog_set (BstTrackSynthDialog *self,
-                            BseItemSeq          *iseq,
+                            BseIt3mSeq          *iseq,
                             SfiProxy             wrepo)
 {
   assert_return (BST_IS_TRACK_SYNTH_DIALOG (self));
diff --git a/beast-gtk/bsttracksynthdialog.hh b/beast-gtk/bsttracksynthdialog.hh
index df50a4f..df5dd67 100644
--- a/beast-gtk/bsttracksynthdialog.hh
+++ b/beast-gtk/bsttracksynthdialog.hh
@@ -50,7 +50,7 @@ GtkWidget* bst_track_synth_dialog_popup    (gpointer                     parent_
                                             SfiProxy                     track,
                                             const gchar                 *candidate_label,
                                             const gchar                 *candidate_tooltip,
-                                            BseItemSeq                  *candidates,
+                                            BseIt3mSeq                  *candidates,
                                             const gchar                 *wrepo_label,
                                             const gchar                 *wrepo_tooltip,
                                             SfiProxy                     wrepo,
@@ -58,7 +58,7 @@ GtkWidget* bst_track_synth_dialog_popup    (gpointer                     parent_
                                             gpointer                     selected_data,
                                             GxkFreeFunc                  selected_cleanup);
 void       bst_track_synth_dialog_set      (BstTrackSynthDialog         *self,
-                                            BseItemSeq                  *iseq,
+                                            BseIt3mSeq                  *iseq,
                                             SfiProxy                     wrepo);
 
 
diff --git a/beast-gtk/bsttrackview.cc b/beast-gtk/bsttrackview.cc
index 41cf9be..6feddc4 100644
--- a/beast-gtk/bsttrackview.cc
+++ b/beast-gtk/bsttrackview.cc
@@ -121,7 +121,7 @@ track_view_fill_value (BstItemView *iview,
       gboolean vbool;
       SfiInt vint;
       SfiProxy snet, wave;
-      BseItemSeq *iseq;
+      BseIt3mSeq *iseq;
       SfiSeq *seq;
     case COL_SEQID:
       sfi_value_take_string (value, g_strdup_format ("%03d", seqid));
@@ -148,14 +148,14 @@ track_view_fill_value (BstItemView *iview,
       break;
     case COL_OUTPUTS:
       bse_proxy_get (item, "outputs", &seq, NULL);
-      iseq = bse_item_seq_from_seq (seq);
+      iseq = bse_it3m_seq_from_seq (seq);
       if (iseq && iseq->n_items == 1)
         g_value_take_string (value, g_strdup_format ("%s", bse_item_get_name_or_type (iseq->items[0])));
       else if (iseq && iseq->n_items > 1)
         g_value_take_string (value, g_strdup_format ("#%u", iseq ? iseq->n_items : 0));
       else
         g_value_set_string (value, "");
-      bse_item_seq_free (iseq);
+      bse_it3m_seq_free (iseq);
       break;
     case COL_POST_SYNTH:
       snet = 0;
@@ -332,12 +332,12 @@ track_view_outputs_cleanup (gpointer data)
 
 static void
 track_view_outputs_changed (gpointer              data,
-                            BseItemSeq           *iseq,
+                            BseIt3mSeq           *iseq,
                             BstItemSeqDialog     *isdialog)
 {
   OutputsPopup *odata = (OutputsPopup*) data;
   gxk_cell_renderer_popup_change (odata->pcell, NULL, FALSE, FALSE);
-  SfiSeq *seq = bse_item_seq_to_seq (iseq);
+  SfiSeq *seq = bse_it3m_seq_to_seq (iseq);
   GValue *value = sfi_value_seq (seq);
   sfi_seq_unref (seq);
   bse_proxy_set_property (odata->item, "outputs", value);
@@ -360,13 +360,13 @@ track_view_outputs_popup (BstTrackView         *self,
       GParamSpec *pspec = bse_proxy_get_pspec (item, "outputs");
       const GValue *value = bse_proxy_get_property (item, "outputs");
       SfiSeq *seq = (SfiSeq*) g_value_get_boxed (value);
-      BseItemSeq *iseq = bse_item_seq_from_seq (seq);
+      BseIt3mSeq *iseq = bse_it3m_seq_from_seq (seq);
       OutputsPopup odata = { self, pcell, item };
       GtkWidget *dialog = bst_item_seq_dialog_popup (self, item,
                                                      pc->label, pc->tooltip, pc->items,
                                                      g_param_spec_get_nick (pspec), g_param_spec_get_blurb 
(pspec), iseq,
                                                      track_view_outputs_changed, g_memdup (&odata, sizeof 
(odata)), track_view_outputs_cleanup);
-      bse_item_seq_free (iseq);
+      bse_it3m_seq_free (iseq);
       gxk_cell_renderer_popup_dialog (pcell, dialog);
     }
 }
@@ -729,7 +729,7 @@ track_view_action_exec (gpointer data,
       item = bst_item_view_get_current (item_view);
       track = Bse::TrackH::down_cast (bse_server.from_proxy (item));
       bse_item_group_undo (song.proxy_id(), "Delete Track");
-      BseItemSeq *iseq = bse_track_list_parts_uniq (item);
+      BseIt3mSeq *iseq = bse_track_list_parts_uniq (item);
       song.remove_track (track);
       for (i = 0; i < iseq->n_items; i++)
         {
diff --git a/beast-gtk/bsttreestores.cc b/beast-gtk/bsttreestores.cc
index dee5c60..12c7ebc 100644
--- a/beast-gtk/bsttreestores.cc
+++ b/beast-gtk/bsttreestores.cc
@@ -328,7 +328,7 @@ bst_child_list_wrapper_setup (GxkListWrapper *self,
   if (parent)
     {
       ProxyStore *ps = g_new0 (ProxyStore, 1);
-      BseItemSeq *iseq;
+      BseIt3mSeq *iseq;
       guint i;
       ps->self = self;
       ps->row_from_proxy = child_list_wrapper_row_from_proxy;
@@ -563,7 +563,7 @@ proxy_cmp_sorted (gconstpointer   value1,
 
 void
 bst_item_seq_store_set (GtkTreeModel   *model,
-                        BseItemSeq     *iseq)
+                        BseIt3mSeq     *iseq)
 {
   g_object_set_data ((GObject*) model, "ProxyStore", NULL);
   if (iseq)
@@ -662,14 +662,14 @@ bst_item_seq_store_lower (GtkTreeModel   *model,
   return row;
 }
 
-BseItemSeq*
+BseIt3mSeq*
 bst_item_seq_store_dup (GtkTreeModel   *model)
 {
   ProxyStore *ps = (ProxyStore*) g_object_get_data ((GObject*) model, "ProxyStore");
-  BseItemSeq *iseq = bse_item_seq_new ();
+  BseIt3mSeq *iseq = bse_it3m_seq_new ();
   SfiRing *ring;
   for (ring = ps->u.pq.items; ring; ring = sfi_ring_walk (ring, ps->u.pq.items))
-    bse_item_seq_append (iseq, (SfiProxy) ring->data);
+    bse_it3m_seq_append (iseq, (SfiProxy) ring->data);
   return iseq;
 }
 
diff --git a/bse/bsebasics.idl b/bse/bsebasics.idl
index bd4a842..1188c64 100644
--- a/bse/bsebasics.idl
+++ b/bse/bsebasics.idl
@@ -319,7 +319,7 @@ sequence NoteSeq {
   Int    notes   = Note ("Note", "", KAMMER_NOTE, ":readwrite"); /* FIXME: s/notes/note/ for pspecs, but not 
the C API */
 };
 interface Item;
-sequence ItemSeq {
+sequence It3mSeq {
   Info   blurb = ("A list of BSE items or derived types.");
   Item   items;
 };
@@ -327,7 +327,7 @@ record PropertyCandidates {
   Info    blurb      = ("A structure describing tentative property values.");
   SfiString  label;
   SfiString  tooltip;
-  ItemSeq items;
+  It3mSeq items;
   TypeSeq partitions = SfiSeq ("Type Partitions", "List of types which may logically partition the list of 
items by type discrimination", STANDARD);
 };
 record NoteDescription
diff --git a/bse/bsebus.cc b/bse/bsebus.cc
index 64b2d83..2926788 100644
--- a/bse/bsebus.cc
+++ b/bse/bsebus.cc
@@ -88,19 +88,19 @@ get_master (BseBus *self)
 
 static void
 bus_list_input_candidates (BseBus     *self,
-                           BseItemSeq *iseq)
+                           BseIt3mSeq *iseq)
 {
   BseItem *item = BSE_ITEM (self);
   bse_item_gather_items_typed (item, iseq, BSE_TYPE_BUS, BSE_TYPE_SONG, FALSE);
   bse_item_gather_items_typed (item, iseq, BSE_TYPE_TRACK, BSE_TYPE_SONG, FALSE);
   BseBus *master = get_master (self);
   if (master)
-    bse_item_seq_remove (iseq, BSE_ITEM (master));
+    bse_it3m_seq_remove (iseq, BSE_ITEM (master));
 }
 
 void
 bse_bus_or_track_list_output_candidates (BseItem    *trackbus,
-                                         BseItemSeq *iseq)
+                                         BseIt3mSeq *iseq)
 {
   if (BSE_IS_BUS (trackbus) || BSE_IS_TRACK (trackbus))
     bse_item_gather_items_typed (trackbus, iseq, BSE_TYPE_BUS, BSE_TYPE_SONG, FALSE);
@@ -122,7 +122,7 @@ bse_bus_get_candidates (BseItem               *item,
       /* remove existing inputs from candidates */
       ring = bse_bus_list_inputs (self);
       while (ring)
-        bse_item_seq_remove (pc->items, (BseItem*) sfi_ring_pop_head (&ring));
+        bse_it3m_seq_remove (pc->items, (BseItem*) sfi_ring_pop_head (&ring));
       /* SYNC: type partitions */
       bse_type_seq_append (pc->partitions, "BseTrack");
       bse_type_seq_append (pc->partitions, "BseBus");
@@ -133,7 +133,7 @@ bse_bus_get_candidates (BseItem               *item,
       /* remove existing outputs */
       ring = bse_bus_list_outputs (self);
       while (ring)
-        bse_item_seq_remove (pc->items, (BseItem*) sfi_ring_pop_head (&ring));
+        bse_it3m_seq_remove (pc->items, (BseItem*) sfi_ring_pop_head (&ring));
       break;
     case PROP_SNET:
       break;
@@ -236,7 +236,7 @@ bus_volume_changed (BseBus *self)
 
 void
 bse_bus_or_track_set_outputs (BseItem        *trackbus,
-                              BseItemSeq     *outputs_iseq)
+                              BseIt3mSeq     *outputs_iseq)
 {
   SfiRing **pbus_outputs;
   /* handle object types */
@@ -247,15 +247,15 @@ bse_bus_or_track_set_outputs (BseItem        *trackbus,
   else
     return;
   /* save user provided order */
-  SfiRing *saved_outputs = bse_item_seq_to_ring (outputs_iseq);
+  SfiRing *saved_outputs = bse_it3m_seq_to_ring (outputs_iseq);
   /* provide sorted rings: bus_outputs, outputs */
   SfiRing *outputs = sfi_ring_sort (sfi_ring_copy (saved_outputs), sfi_pointer_cmp, NULL);
   *pbus_outputs = sfi_ring_sort (*pbus_outputs, sfi_pointer_cmp, NULL);
   /* get all output candidates */
-  BseItemSeq *iseq = bse_item_seq_new();
+  BseIt3mSeq *iseq = bse_it3m_seq_new();
   bse_bus_or_track_list_output_candidates (trackbus, iseq);
-  SfiRing *candidates = sfi_ring_sort (bse_item_seq_to_ring (iseq), sfi_pointer_cmp, NULL);
-  bse_item_seq_free (iseq);
+  SfiRing *candidates = sfi_ring_sort (bse_it3m_seq_to_ring (iseq), sfi_pointer_cmp, NULL);
+  bse_it3m_seq_free (iseq);
   /* constrain the new output list */
   SfiRing *ring = sfi_ring_intersection (outputs, candidates, sfi_pointer_cmp, NULL);
   sfi_ring_free (candidates);
@@ -285,20 +285,20 @@ bse_bus_set_property (GObject      *object,
   switch (param_id)
     {
       SfiRing *inputs, *candidates, *ring, *saved_inputs;
-      BseItemSeq *iseq;
+      BseIt3mSeq *iseq;
       BseItem *parent;
       gboolean vbool;
     case PROP_INPUTS:
       /* save user provided order */
-      saved_inputs = bse_item_seq_to_ring ((BseItemSeq*) g_value_get_boxed (value));
+      saved_inputs = bse_it3m_seq_to_ring ((BseIt3mSeq*) g_value_get_boxed (value));
       /* provide sorted rings: self->inputs, inputs */
       inputs = sfi_ring_sort (sfi_ring_copy (saved_inputs), sfi_pointer_cmp, NULL);
       self->inputs = sfi_ring_sort (self->inputs, sfi_pointer_cmp, NULL);
       /* get all input candidates */
-      iseq = bse_item_seq_new();
+      iseq = bse_it3m_seq_new();
       bus_list_input_candidates (self, iseq);
-      candidates = sfi_ring_sort (bse_item_seq_to_ring (iseq), sfi_pointer_cmp, NULL);
-      bse_item_seq_free (iseq);
+      candidates = sfi_ring_sort (bse_it3m_seq_to_ring (iseq), sfi_pointer_cmp, NULL);
+      bse_it3m_seq_free (iseq);
       /* constrain the new input list */
       ring = sfi_ring_intersection (inputs, candidates, sfi_pointer_cmp, NULL);
       sfi_ring_free (candidates);
@@ -318,7 +318,7 @@ bse_bus_set_property (GObject      *object,
       sfi_ring_free (saved_inputs);
       break;
     case PROP_OUTPUTS:
-      bse_bus_or_track_set_outputs (BSE_ITEM (self), (BseItemSeq*) g_value_get_boxed (value));
+      bse_bus_or_track_set_outputs (BSE_ITEM (self), (BseIt3mSeq*) g_value_get_boxed (value));
       break;
     case PROP_SNET:
       g_object_set_property (G_OBJECT (self), "BseSubSynth::snet", value);
@@ -409,22 +409,22 @@ bse_bus_get_property (GObject    *object,
   switch (param_id)
     {
       BseItem *parent;
-      BseItemSeq *iseq;
+      BseIt3mSeq *iseq;
       SfiRing *ring;
     case PROP_INPUTS:
-      iseq = bse_item_seq_new();
+      iseq = bse_it3m_seq_new();
       ring = bse_bus_list_inputs (self);
       while (ring)
-        bse_item_seq_append (iseq, (BseItem*) sfi_ring_pop_head (&ring));
+        bse_it3m_seq_append (iseq, (BseItem*) sfi_ring_pop_head (&ring));
       g_value_take_boxed (value, iseq);
       break;
     case PROP_OUTPUTS:
-      iseq = bse_item_seq_new();
+      iseq = bse_it3m_seq_new();
       ring = bse_bus_list_outputs (self);
       while (ring)
-        bse_item_seq_append (iseq, (BseItem*) sfi_ring_pop_head (&ring));
+        bse_it3m_seq_append (iseq, (BseItem*) sfi_ring_pop_head (&ring));
       if (!ring && get_master (self) == self)
-        bse_item_seq_append (iseq, BSE_ITEM (self)->parent);    /* requires proxy_notifies on parent */
+        bse_it3m_seq_append (iseq, BSE_ITEM (self)->parent);    /* requires proxy_notifies on parent */
       g_value_take_boxed (value, iseq);
       break;
     case PROP_SNET:
@@ -651,7 +651,7 @@ bse_bus_connect (BseBus  *self,
                  BseItem *trackbus)
 {
   /* get all input candidates */
-  BseItemSeq *iseq = bse_item_seq_new();
+  BseIt3mSeq *iseq = bse_it3m_seq_new();
   bus_list_input_candidates (self, iseq);
   /* find trackbus */
   gboolean found_candidate = FALSE;
@@ -662,7 +662,7 @@ bse_bus_connect (BseBus  *self,
         found_candidate = TRUE;
         break;
       }
-  bse_item_seq_free (iseq);
+  bse_it3m_seq_free (iseq);
   /* add trackbus if valid */
   if (found_candidate)
     return bse_bus_connect_unchecked (self, trackbus);
@@ -885,12 +885,12 @@ bse_bus_class_init (BseBusClass *klass)
                                                      * to be preserved to match the GUI order of displayed 
objects.
                                                      */
                                                     _("Synthesis signals (from tracks and busses) used as 
bus input"),
-                                                    BSE_TYPE_ITEM_SEQ, SFI_PARAM_GUI ":item-sequence"));
+                                                    BSE_TYPE_IT3M_SEQ, SFI_PARAM_GUI ":item-sequence"));
   bse_object_class_add_param (object_class, _("Signal Outputs"),
                               PROP_OUTPUTS,
                               bse_param_spec_boxed ("outputs", _("Output Signals"),
                                                     _("Mixer busses used as output for synthesis signals"),
-                                                    BSE_TYPE_ITEM_SEQ, SFI_PARAM_GUI ":item-sequence"));
+                                                    BSE_TYPE_IT3M_SEQ, SFI_PARAM_GUI ":item-sequence"));
   bse_object_class_add_param (object_class, NULL, PROP_SNET, bse_param_spec_object ("snet", NULL, NULL, 
BSE_TYPE_CSYNTH, SFI_PARAM_READWRITE ":skip-undo"));
   bse_object_class_add_param (object_class, _("Internals"),
                              PROP_MASTER_OUTPUT,
diff --git a/bse/bsebus.hh b/bse/bsebus.hh
index 0186971..cf41620 100644
--- a/bse/bsebus.hh
+++ b/bse/bsebus.hh
@@ -58,9 +58,9 @@ void            bse_bus_change_solo             (BseBus         *self,
                                                  gboolean        solo_muted);
 #define         bse_bus_create_stack(b)         bse_bus_get_stack (b,0,0,0)
 void    bse_bus_or_track_list_output_candidates (BseItem        *trackbus,
-                                                 BseItemSeq     *iseq);
+                                                 BseIt3mSeq     *iseq);
 void    bse_bus_or_track_set_outputs            (BseItem        *trackbus,
-                                                 BseItemSeq     *iseq);
+                                                 BseIt3mSeq     *iseq);
 
 /* --- channels --- */
 enum
diff --git a/bse/bsecontainer.cc b/bse/bsecontainer.cc
index d0e5812..1c1b33a 100644
--- a/bse/bsecontainer.cc
+++ b/bse/bsecontainer.cc
@@ -384,21 +384,21 @@ static gboolean
 list_items (BseItem *item,
             gpointer data)
 {
-  BseItemSeq *iseq = (BseItemSeq*) data;
+  BseIt3mSeq *iseq = (BseIt3mSeq*) data;
 
-  bse_item_seq_append (iseq, item);
+  bse_it3m_seq_append (iseq, item);
 
   return TRUE;
 }
 
-BseItemSeq*
+BseIt3mSeq*
 bse_container_list_children (BseContainer *container)
 {
-  BseItemSeq *iseq;
+  BseIt3mSeq *iseq;
 
   assert_return (BSE_IS_CONTAINER (container), NULL);
 
-  iseq = bse_item_seq_new ();
+  iseq = bse_it3m_seq_new ();
   if (container->n_items)
     {
       assert_return (BSE_CONTAINER_GET_CLASS (container)->forall_items != NULL, NULL); /* paranoid */
diff --git a/bse/bsecontainer.hh b/bse/bsecontainer.hh
index aae97a5..283afd6 100644
--- a/bse/bsecontainer.hh
+++ b/bse/bsecontainer.hh
@@ -48,7 +48,7 @@ struct BseContainerClass : BseSourceClass {
 void           bse_container_forall_items      (BseContainer   *container,
                                                 BseForallItemsFunc func,
                                                 gpointer        data);
-BseItemSeq*    bse_container_list_children     (BseContainer   *container);
+BseIt3mSeq*    bse_container_list_children     (BseContainer   *container);
 guint          bse_container_get_item_seqid    (BseContainer   *container,
                                                 BseItem        *item);
 BseItem*       bse_container_get_item          (BseContainer   *container,
diff --git a/bse/bsecontainer.proc b/bse/bsecontainer.proc
index 63680b7..221f1b2 100644
--- a/bse/bsecontainer.proc
+++ b/bse/bsecontainer.proc
@@ -13,7 +13,7 @@ LICENSE = "GNU Lesser General Public License";
 METHOD (BseContainer, list-children) {
   HELP = _("Retrieve all immediate children of a container");
   IN   = bse_param_spec_object ("container", NULL, NULL, BSE_TYPE_CONTAINER, SFI_PARAM_STANDARD);
-  OUT  = bse_param_spec_boxed ("item_list", NULL, NULL, BSE_TYPE_ITEM_SEQ, SFI_PARAM_STANDARD);
+  OUT  = bse_param_spec_boxed ("item_list", NULL, NULL, BSE_TYPE_IT3M_SEQ, SFI_PARAM_STANDARD);
 } BODY (BseProcedureClass *proc,
        const GValue      *in_values,
        GValue            *out_values)
diff --git a/bse/bseitem.cc b/bse/bseitem.cc
index eb0fa5a..6a5623b 100644
--- a/bse/bseitem.cc
+++ b/bse/bseitem.cc
@@ -286,7 +286,7 @@ bse_item_compat_setup (BseItem         *self,
 typedef struct {
   BseItem              *item;
   void                 *data;
-  BseItemSeq           *iseq;
+  BseIt3mSeq           *iseq;
   GType                 base_type;
   BseItemCheckContainer ccheck;
   BseItemCheckProxy     pcheck;
@@ -301,7 +301,7 @@ gather_child (BseItem *child,
   if (child != gdata->item && !BSE_ITEM_INTERNAL (child) &&
       g_type_is_a (G_OBJECT_TYPE (child), gdata->base_type) &&
       (!gdata->pcheck || gdata->pcheck (child, gdata->item, gdata->data)))
-    bse_item_seq_append (gdata->iseq, child);
+    bse_it3m_seq_append (gdata->iseq, child);
   return TRUE;
 }
 
@@ -318,9 +318,9 @@ gather_child (BseItem *child,
  * starting out with @a item. For each container passing @a ccheck(), all
  * immediate children are tested for addition with @a pcheck.
  */
-BseItemSeq*
+BseIt3mSeq*
 bse_item_gather_items (BseItem              *item,
-                       BseItemSeq           *iseq,
+                       BseIt3mSeq           *iseq,
                        GType                 base_type,
                        BseItemCheckContainer ccheck,
                        BseItemCheckProxy     pcheck,
@@ -380,9 +380,9 @@ gather_typed_acheck (BseItem  *proxy,
  * and @a proxy_type respectively. Gathered items may not be ancestors
  * of @a item if @a allow_ancestor is FALSE.
  */
-BseItemSeq*
+BseIt3mSeq*
 bse_item_gather_items_typed (BseItem              *item,
-                             BseItemSeq           *iseq,
+                             BseIt3mSeq           *iseq,
                              GType                 proxy_type,
                              GType                 container_type,
                              gboolean              allow_ancestor)
@@ -410,7 +410,7 @@ bse_item_get_candidates (BseItem                *item,
   if (!pspec)
     return FALSE;
   if (!pc->items)
-    pc->items = bse_item_seq_new();
+    pc->items = bse_it3m_seq_new();
   if (!pc->partitions)
     pc->partitions = bse_type_seq_new();
   klass = (BseItemClass*) g_type_class_peek (pspec->owner_type);
diff --git a/bse/bseitem.hh b/bse/bseitem.hh
index dd449ce..c4d604a 100644
--- a/bse/bseitem.hh
+++ b/bse/bseitem.hh
@@ -64,14 +64,14 @@ typedef gboolean (*BseItemCheckProxy)        (BseItem        *proxy,
 
 
 /* --- prototypes --- */
-BseItemSeq*    bse_item_gather_items         (BseItem                *item,
-                                              BseItemSeq             *iseq,
+BseIt3mSeq*    bse_item_gather_items         (BseItem                *item,
+                                              BseIt3mSeq             *iseq,
                                               GType                   base_type,
                                               BseItemCheckContainer   ccheck,
                                               BseItemCheckProxy       pcheck,
                                               gpointer                data);
-BseItemSeq*    bse_item_gather_items_typed   (BseItem                *item,
-                                              BseItemSeq             *iseq,
+BseIt3mSeq*    bse_item_gather_items_typed   (BseItem                *item,
+                                              BseIt3mSeq             *iseq,
                                               GType                   proxy_type,
                                               GType                   container_type,
                                               gboolean                allow_ancestor);
diff --git a/bse/bseproject.proc b/bse/bseproject.proc
index e752a84..87fea3f 100644
--- a/bse/bseproject.proc
+++ b/bse/bseproject.proc
@@ -262,14 +262,14 @@ METHOD (BseProject, get-supers) {
   HELP  = "Retrieve all supers of this project.";
   IN    = bse_param_spec_object ("project", NULL, NULL,
                                  BSE_TYPE_PROJECT, SFI_PARAM_STANDARD);
-  OUT   = bse_param_spec_boxed ("super_list", NULL, NULL, BSE_TYPE_ITEM_SEQ, SFI_PARAM_STANDARD);
+  OUT   = bse_param_spec_boxed ("super_list", NULL, NULL, BSE_TYPE_IT3M_SEQ, SFI_PARAM_STANDARD);
 } BODY (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
 {
   /* extract parameter values */
   BseProject *project = (BseProject*) bse_value_get_object (in_values++);
-  BseItemSeq *iseq;
+  BseIt3mSeq *iseq;
   GSList *slist;
 
   /* check parameters */
@@ -277,9 +277,9 @@ METHOD (BseProject, get-supers) {
     return Bse::ERROR_PROC_PARAM_INVAL;
 
   /* action */
-  iseq = bse_item_seq_new ();
+  iseq = bse_it3m_seq_new ();
   for (slist = project->supers; slist; slist = slist->next)
-    bse_item_seq_append (iseq, (BseItem*) slist->data);
+    bse_it3m_seq_append (iseq, (BseItem*) slist->data);
 
   /* set output parameters */
   bse_value_take_boxed (out_values++, iseq);
diff --git a/bse/bsetrack.cc b/bse/bsetrack.cc
index 0acb8ad..6566ba9 100644
--- a/bse/bsetrack.cc
+++ b/bse/bsetrack.cc
@@ -283,7 +283,7 @@ bse_track_get_candidates (BseItem               *item,
       bse_bus_or_track_list_output_candidates (BSE_ITEM (self), pc->items);
       /* remove existing outputs */
       for (ring = self->bus_outputs; ring; ring = sfi_ring_walk (ring, self->bus_outputs))
-        bse_item_seq_remove (pc->items, (BseItem*) ring->data);
+        bse_it3m_seq_remove (pc->items, (BseItem*) ring->data);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
@@ -523,7 +523,7 @@ bse_track_set_property (GObject      *object,
        }
       break;
     case PROP_OUTPUTS:
-      bse_bus_or_track_set_outputs (BSE_ITEM (self), (BseItemSeq*) g_value_get_boxed (value));
+      bse_bus_or_track_set_outputs (BSE_ITEM (self), (BseIt3mSeq*) g_value_get_boxed (value));
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
@@ -541,7 +541,7 @@ bse_track_get_property (GObject    *object,
 
   switch (param_id)
     {
-      BseItemSeq *iseq;
+      BseIt3mSeq *iseq;
       SfiRing *ring;
     case PROP_MUTED:
       sfi_value_set_bool (value, self->muted_SL);
@@ -553,9 +553,9 @@ bse_track_get_property (GObject    *object,
       bse_value_set_object (value, self->pnet);
       break;
     case PROP_OUTPUTS:
-      iseq = bse_item_seq_new();
+      iseq = bse_it3m_seq_new();
       for (ring = self->bus_outputs; ring; ring = sfi_ring_walk (ring, self->bus_outputs))
-        bse_item_seq_append (iseq, (BseItem*) ring->data);
+        bse_it3m_seq_append (iseq, (BseItem*) ring->data);
       g_value_take_boxed (value, iseq);
       break;
     case PROP_WAVE:
@@ -1054,7 +1054,7 @@ bse_track_class_init (BseTrackClass *klass)
                               PROP_OUTPUTS,
                               bse_param_spec_boxed ("outputs", _("Output Signals"),
                                                     _("Mixer busses used as output for this track"),
-                                                    BSE_TYPE_ITEM_SEQ, SFI_PARAM_GUI ":item-sequence"));
+                                                    BSE_TYPE_IT3M_SEQ, SFI_PARAM_GUI ":item-sequence"));
   signal_changed = bse_object_class_add_asignal (object_class, "changed", G_TYPE_NONE, 0);
 }
 
diff --git a/bse/bsetrack.proc b/bse/bsetrack.proc
index 47e46c4..eaa8110 100644
--- a/bse/bsetrack.proc
+++ b/bse/bsetrack.proc
@@ -43,7 +43,7 @@ METHOD (BseTrack, list-parts-uniq) {
   IN    = bse_param_spec_object ("track", "Track", NULL,
                                 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
   OUT   = bse_param_spec_boxed ("part_list", "Part List", NULL,
-                               BSE_TYPE_ITEM_SEQ, SFI_PARAM_STANDARD); // FIXME: should use BsePartSeq here
+                               BSE_TYPE_IT3M_SEQ, SFI_PARAM_STANDARD); // FIXME: should use BsePartSeq here
 }
 BODY (BseProcedureClass *proc,
       const GValue      *in_values,
@@ -65,7 +65,7 @@ BODY (BseProcedureClass *proc,
   bse_track_part_seq_free (tpseq);
   ring = sfi_ring_sort (ring, sfi_pointer_cmp, NULL);
   ring = sfi_ring_uniq (ring, sfi_pointer_cmp, NULL);
-  bse_value_take_boxed (out_values++, bse_item_seq_from_ring (ring));
+  bse_value_take_boxed (out_values++, bse_it3m_seq_from_ring (ring));
   sfi_ring_free (ring);
 
   return Bse::ERROR_NONE;
diff --git a/bse/bseutils.cc b/bse/bseutils.cc
index 05112e0..acefa21 100644
--- a/bse/bseutils.cc
+++ b/bse/bseutils.cc
@@ -105,7 +105,7 @@ bse_property_candidate_relabel (BsePropertyCandidates *pc,
 }
 
 void
-bse_item_seq_remove (BseItemSeq *iseq,
+bse_it3m_seq_remove (BseIt3mSeq *iseq,
                      BseItem    *item)
 {
   guint i;
@@ -120,7 +120,7 @@ bse_item_seq_remove (BseItemSeq *iseq,
 }
 
 SfiRing*
-bse_item_seq_to_ring (BseItemSeq *iseq)
+bse_it3m_seq_to_ring (BseIt3mSeq *iseq)
 {
   SfiRing *ring = NULL;
   guint i;
@@ -130,13 +130,13 @@ bse_item_seq_to_ring (BseItemSeq *iseq)
   return ring;
 }
 
-BseItemSeq*
-bse_item_seq_from_ring (SfiRing *ring)
+BseIt3mSeq*
+bse_it3m_seq_from_ring (SfiRing *ring)
 {
-  BseItemSeq *iseq = bse_item_seq_new();
+  BseIt3mSeq *iseq = bse_it3m_seq_new();
   SfiRing *node;
   for (node = ring; node; node = sfi_ring_walk (node, ring))
-    bse_item_seq_append (iseq, (BseItem*) node->data);
+    bse_it3m_seq_append (iseq, (BseItem*) node->data);
   return iseq;
 }
 
diff --git a/bse/bseutils.hh b/bse/bseutils.hh
index 1d8d4ef..f43b491 100644
--- a/bse/bseutils.hh
+++ b/bse/bseutils.hh
@@ -24,10 +24,10 @@ guint               bse_note_sequence_length         (BseNoteSequence       *rec
 void                bse_property_candidate_relabel   (BsePropertyCandidates *pc,
                                                       const gchar           *label,
                                                       const gchar           *tooltip);
-void                bse_item_seq_remove              (BseItemSeq            *iseq,
+void                bse_it3m_seq_remove              (BseIt3mSeq            *iseq,
                                                       BseItem               *item);
-SfiRing*            bse_item_seq_to_ring             (BseItemSeq            *iseq);
-BseItemSeq*         bse_item_seq_from_ring           (SfiRing               *ring);
+SfiRing*            bse_it3m_seq_to_ring             (BseIt3mSeq            *iseq);
+BseIt3mSeq*         bse_it3m_seq_from_ring           (SfiRing               *ring);
 
 
 /* --- debugging --- */
diff --git a/bse/bsewaveosc.proc b/bse/bsewaveosc.proc
index 7e1c59c..4492354 100644
--- a/bse/bsewaveosc.proc
+++ b/bse/bsewaveosc.proc
@@ -32,7 +32,7 @@ METHOD (BseWaveOsc, request-pcm-position) {
 
 PROCEDURE (bse-wave-osc-mass-seek-perc, "Seek Wave Oscillators") {
   HELP = "Seek a list of wave oscillators to a pcm position given in percentage. The oscillators will seek 
to the given position syncronously.";
-  IN    = bse_param_spec_boxed ("wosc-seq", "Wave Oscilators", NULL, BSE_TYPE_ITEM_SEQ, SFI_PARAM_STANDARD); 
// FIXME: using BseItemSeq because BseWaveOscSeq requires idl+C++
+  IN    = bse_param_spec_boxed ("wosc-seq", "Wave Oscilators", NULL, BSE_TYPE_IT3M_SEQ, SFI_PARAM_STANDARD); 
// FIXME: using BseIt3mSeq because BseWaveOscSeq requires idl+C++
   IN   = sfi_pspec_real ("pos_perc", NULL, NULL,
                          0, 0, 100, 1,
                          SFI_PARAM_STANDARD);
@@ -41,7 +41,7 @@ PROCEDURE (bse-wave-osc-mass-seek-perc, "Seek Wave Oscillators") {
        GValue            *out_values)
 {
   /* extract parameter values */
-  BseItemSeq *iseq = (BseItemSeq*) bse_value_get_boxed (in_values++);
+  BseIt3mSeq *iseq = (BseIt3mSeq*) bse_value_get_boxed (in_values++);
   gfloat      pos  = sfi_value_get_real (in_values++);
   guint i, n = iseq ? iseq->n_items : 0;
   BseWaveOsc **woscs = (BseWaveOsc**) g_alloca (sizeof (BseWaveOsc*) * n);


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/beast-gtk/bsttreestores.hh b/beast-gtk/bsttreestores.hh
index 2e61b2e..ba64c86 100644
--- a/beast-gtk/bsttreestores.hh
+++ b/beast-gtk/bsttreestores.hh
@@ -36,10 +36,10 @@ enum {
   BST_PROXY_STORE_TYPE,
   BST_PROXY_STORE_N_COLS
 };
 /* store based on a BseItemSeq */
 GtkTreeModel*   bst_item_seq_store_new                  (gboolean        sorted);
 void            bst_item_seq_store_set                  (GtkTreeModel   *self,
-                                                         BseItemSeq     *iseq);
+                                                         BseIt3mSeq     *iseq);
 gint            bst_item_seq_store_add                  (GtkTreeModel   *self,
                                                          SfiProxy        proxy);
 gint            bst_item_seq_store_remove               (GtkTreeModel   *self,
@@ -52,7 +52,7 @@ gint            bst_item_seq_store_lower                (GtkTreeModel   *self,
                                                          SfiProxy        proxy);
 gboolean        bst_item_seq_store_can_lower            (GtkTreeModel   *self,
                                                          SfiProxy        proxy);
-BseItemSeq*     bst_item_seq_store_dup                  (GtkTreeModel   *self);
+BseIt3mSeq*     bst_item_seq_store_dup                  (GtkTreeModel   *self);
 SfiProxy        bst_item_seq_store_get_proxy            (GtkTreeModel   *self,
                                                          gint            row);
 SfiProxy        bst_item_seq_store_get_from_iter        (GtkTreeModel   *self,
@@ -36,10 +36,10 @@ enum {
   BST_PROXY_STORE_N_COLS
 };
-/* store based on a BseItemSeq */
+/* store based on a BseIt3mSeq */
 GtkTreeModel*   bst_item_seq_store_new                  (gboolean        sorted);
 void            bst_item_seq_store_set                  (GtkTreeModel   *self,